<?php

/**
 * Module: Icon Teaser
 * Display a brief text with a link and use hundreds of built-in icons
 *
 * @author 		SpyroSol
 * @category 	BuilderModules
 * @package 	Spyropress
 */

class Spyropress_Module_Icon_Teaser extends SpyropressBuilderModule {

    /**
     * Constructor
     */
    public function __construct() {

        // Widget variable settings
        $this->path = dirname(__FILE__);
        $this->cssclass = 'module-icon-teaser';
        $this->description = __( 'Display a brief text with a link and use of icons.', 'flathost' );
        $this->id_base = 'spyropress_icon_teaser';
        $this->name = __( 'Icon Teaser', 'flathost' );

        $this->templates['view-one'] = array( 'view' => 'view-one.php', 'label' =>__( 'Top Icons', 'flathost' ) );
        $this->templates['view-two'] = array( 'view' => 'view-two.php', 'label' =>__( 'Left Icons', 'flathost' ) );
        
        // Fields
        $this->fields = array (
             array(

                'label' => __( 'Template', 'flathost' ),

                'id' => 'template',

                'class' => 'enable_changer section-full',

                'type' => 'select',

                'options' => $this->get_option_templates()

            ),
            
            array(

                'label' => __( 'Number of Columns', 'flathost' ),

                'id' => 'columns',

                'type' => 'range_slider',

                'std' => 3,

                'max' => 4

            ),
            
            array(

                'label' => __( 'Service', 'flathost' ),

                'id' => 'services',

                'type' => 'repeater',

                'item_title' => 'heading',

                'fields' => array(
                    array(
                        'label' => __( 'Title', 'flathost' ),
                        'id' => 'title',
                        'type' => 'text'
                    ),
                    
                    array(
                        'label' => __( 'Upload Icon', 'flathost' ),
                        'id' => 'icon',
                        'type' => 'upload',
                        'desc' => __('You can upload Icon Image or insert hosted image url Be Alert "you can upload icon image Or choose Fontawesome Icon"', 'flathost')
                    ),
                    
                    array(
                        'label' => __( 'Icon', 'flathost' ),
                        'id' => 'fa_icon',
                        'type' => 'select',
                        'options' => spyropress_get_options_fontawesome_icons(),
                        'desc' => __('You can choose Fontawesome Icon Be Alert "you can upload icon image Or choose Fontawesome Icon"', 'flathost')
                    ),
                    
                    array(
                        'label' => __( 'Link', 'flathost' ),
                        'id' => 'link',
                        'type' => 'text'
                    ),
        
                    array(
                        'label' => __( 'Content', 'flathost' ),
                        'id' => 'content',
                        'type' => 'textarea',
                        'rows' => 6
                    ),
                )
            ),
            
            array(
		'label' => __( 'Link Action', 'flathost' ),
		'id' => 'action',
	        'type' => 'checkbox',
	        'options' => array(
	            '1' => __( 'Activate link action in new window.', 'flathost' ),
	        )
	    ),
           
        );
        
        $this->create_widget();
    }

    function widget( $args, $instance ) {
        
        // extracting info

        extract($args); extract($instance);

        $template = !empty( $instance['template'] ) ? $instance['template'] : 'view-one';

        include $this->get_view( $template );
    }
    
     function image_teaser_generator( $item, $atts ){
       
        $action = (isset( $atts['action'] ) && !empty( $atts['action'][0] ))? 'target="_blank"' : '';
        $link = isset( $item['link'] )? $item['link'] : '';
        $link_before = !empty( $link )? '<a href="'. esc_url( $link ) .'" '. $action .'>' : '';
        $link_after = !empty( $link )? '</a>' : '';
        $item['icon'] = isset( $item['icon'] ) ? $item['icon'] : '';
		$item['fa_icon'] = isset( $item['fa_icon'] ) ? $item['fa_icon'] : '';
		$item['title'] = isset( $item['title'] ) ? $item['title'] : '';
		$item['content'] = isset( $item['content'] ) ? $item['content'] : '';
        $icon = isset( $item['icon'] )? '<img src="'. esc_url( $item['icon'] ) .'" width="85" height="88" alt="secure">' : '<i class="fa '. $item['fa_icon'] .'"></i>'; 
        
        return 
        '<div class="' . esc_attr( $atts['column_class'] ) . '">
            '. $link_before .'
              <div class="img-thumbnail"> '. $icon .'
                <div class="caption">
                  <h4>'. esc_html( $item['title'] ) .'</h4>
                  <p>'. esc_html( $item['content'] ) .'</p>
                </div>
            </div>
           '. $link_after .'
        </div>';
        
     }
     
     function image_second_teaser_generator( $item, $atts ){
     
        $action = (isset( $atts['action'] ) && !empty( $atts['action'] ))? 'target="_blank"' : '';
        $link = isset( $item['link'] )? $item['link'] : '';
        $link_before = !empty( $link )? '<a href="'. esc_url( $link ) .'" '. $action .'>' : '';
        $link_after = !empty( $link )? '</a>' : '';
        $item['icon'] = isset($item['icon']) ? $item['icon'] : ''; 
		$item['fa_icon'] = isset($item['fa_icon']) ? $item['fa_icon'] : ''; 
		$item['title'] = isset($item['title']) ? $item['title'] : ''; 
		$item['content'] = isset($item['content']) ? $item['content'] : ''; 
        $icon = isset( $item['icon'] )? '<img src="'. esc_url( $item['icon'] ) .'" width="85" height="88" alt="secure">' : '<i class="fa '. $item['fa_icon'] .'"></i>'; 
       
        
        return 
        '<div class="' . esc_attr( $atts['column_class'] ) . '">
           '. $link_before .'	
           '. $icon .'
            <h4>'. esc_html( $item['title'] ) .'</h4>
            <p>'. esc_html( $item['content'] ) .'</p>  
           '. $link_after .'              
        </div>';
        
     }
     

}
spyropress_builder_register_module( 'Spyropress_Module_Icon_Teaser' );