<?php

/**
 * Option/Settings Helper Functions
 *
 * @category Utilities
 * @package Spyropress
 *
 */

/** Option Getter and Formatter **********************/

function get_float_class( $float ) {
    
    // check for null
    if ( ! $float ) return;

    $allowed_floats = array( 'left' => 'pull-left', 'right' => 'pull-right' );

    if ( in_array( $float, array_keys( $allowed_floats ) ) )
        $float = $allowed_floats[$float];

    return $float;
}

/**
 * Row Class
 */
function get_row_class( $return = false ) {
    global $spyropress;

    if ( $return )
        return $spyropress->row_class;
    echo ''.$spyropress->row_class;
}

/**
 * Column Class
 */
function get_column_class( $column ) {
    if( 'skt' == get_html_framework() ) return get_skeleton_col_class( $column );
    
    if( 'bs' == get_html_framework() ) return get_bootstrap_class( $column );
    
    if( 'bs3' == get_html_framework() ) return get_bootstrap3_class( $column );
    
    if( 'fd3' == get_html_framework() ) return get_foundation3_col_class( $column );
}

/**
 * Bootstrap Class
 */
function get_bootstrap_class( $column ) {

    $class = 'span12';

    switch ( $column ) {
        case 2:
            $class = 'span6';
            break;
        case 3:
            $class = 'span4';
            break;
        case 4:
            $class = 'span3';
            break;
        case 6:
            $class = 'span2';
            break;
    }

    return $class;
}

/**
 * Bootstrap Class
 */
function get_bootstrap3_class( $column ) {

    $class = 'col-md-12';

    switch ( $column ) {
        case 2:
            $class = 'col-md-6';
            break;
        case 3:
            $class = 'col-md-4';
            break;
        case 4:
            $class = 'col-md-3';
            break;
        case 6:
            $class = 'col-md-2';
            break;
    }

    return $class;
}

/**
 * Skeleton Classes
 */
function get_skeleton_col_class( $column ) {

    $class = get_skeleton_class( 16 );

    switch ( $column ) {
        case 2:
            $class = get_skeleton_class( 8 );
            break;
        case 3:
            $class = get_skeleton_class( '1/3' );
            break;
        case 4:
            $class = get_skeleton_class( 4 );
            break;
        case 8:
            $class = get_skeleton_class( 2 );
            break;
    }

    return $class;
}

function get_skeleton_class( $column ) {
    
    $classes = array(
        1 => 'one columns',
        2 => 'two columns',
        3 => 'three columns',
        4 => 'four columns',
        5 => 'five columns',
        6 => 'six columns',
        7 => 'seven columns',
        8 => 'eight columns',
        9 => 'nine columns',
        10 => 'ten columns',
        11 => 'eleven columns',
        12 => 'twelve columns',
        13 => 'thirteen columns',
        14 => 'fourteen columns',
        15 => 'fifteen columns',
        16 => 'sixteen columns',
        '1/3' => 'one-third column',
        '2/3' => 'two-thirds column',
    );
    
    return $classes[$column];
}

function get_admin_column_class( $column ) {
    
    $class = '';
    if( 12 == get_grid_columns() ) {

        $class = 'span12';
        
        switch ( $column ) {
            case 2:
                $class = 'span6';
                break;
            case 3:
                $class = 'span4';
                break;
            case 4:
                $class = 'span3';
                break;
            case 6:
                $class = 'span2';
                break;
        }
    }
    elseif( 16 == get_grid_columns() ) {

        $class = 'span16';
        
        switch ( $column ) {
            case 2:
                $class = 'span8';
                break;
            case 3:
                $class = 'span1by3';
                break;
            case 4:
                $class = 'span4';
                break;
            case 8:
                $class = 'span2';
                break;
        }
    }
    
    return $class;
}

/**
 * Foundation3 Classes
 */

function get_foundation3_col_class( $column ) {

    $class = get_foundation3_class( 12 );

    switch ( $column ) {
        case 2:
            $class = get_foundation3_class( 6 );
            break;
        case 3:
            $class = get_foundation3_class( 4 );
            break;
        case 4:
            $class = get_foundation3_class( 3 );
            break;
        case 6:
            $class = get_foundation3_class( 2 );
            break;
    }

    return $class;
}

function get_foundation3_class( $column ) {

    $classes = array(
        1 => 'one columns',
        2 => 'two columns',
        3 => 'three columns',
        4 => 'four columns',
        5 => 'five columns',
        6 => 'six columns',
        7 => 'seven columns',
        8 => 'eight columns',
        9 => 'nine columns',
        10 => 'ten columns',
        11 => 'eleven columns',
        12 => 'twelve columns'
    );
    
    return $classes[$column];
}

/**
 * Get HTML Framework
 */
function get_html_framework() {
    global $spyropress;
    return $spyropress->framework;
}

/**
 * Get Grid Column
 */
function get_grid_columns() {
    global $spyropress;
    return $spyropress->grid_columns;
}

/**
 * First Column Class accoring to framework
 */
function get_first_column_class() {
    
    // Skeleton
    if( 'skt' == get_html_framework() ) return 'alpha';
    
    // Others
    return 'column_first';
}

/**
 * Last Column Class accoring to framework
 */
function get_last_column_class() {
    
    // Skeleton
    if( 'skt' == get_html_framework() ) return 'omega';
    
    // Foundation
    if( 'fd3' == get_html_framework() ) return 'end';
    
    // Others
    return 'column_last';
}

/** Data Sources for Post Type and Taxonomies **********************/

/**
 * Buckets
 */
function spyropress_get_buckets() {
    
    $buckets = array();
    
    if ( ! post_type_exists( 'bucket' ) ) return $buckets;
    
    // get posts
    $args = array(
        'post_type' => 'bucket',
        'posts_per_page' => -1,
        'orderby' => 'title',
        'order' => 'asc'
    );
    $posts = get_posts( $args );
    if ( !empty( $posts ) ) {
        foreach ( $posts as $post ) {
            $buckets[$post->ID] = $post->post_title;
        }
    }

    return $buckets;
}

/**
 * Custom Taxonomies
 */
function spyropress_get_taxonomies( $tax = '' ) {
    
    if ( ! $tax ) return array();

    $terms = get_terms( $tax );
    $taxs = array();
    if ( !empty( $terms ) )
        foreach ( $terms as $term )
            $taxs[$term->slug] = $term->name;

    return $taxs;
}

function spyropress_get_options_fontawesome_icons(){
    
     return array(
        'fa-adjust' => __( 'Adjust', 'flathost' ),
        'fa-adn' => __( 'Adn', 'flathost' ),
        'fa-align-center' => __( 'Align Center', 'flathost' ),
        'fa-align-justify' => __( 'Align Justify', 'flathost' ),
        'fa-align-left' => __( 'Align Left', 'flathost' ),
        'fa-align-right' => __( 'Align Right', 'flathost' ),
        'fa-ambulance' => __( 'Ambulance', 'flathost' ),
        'fa-anchor' => __( 'Anchor', 'flathost' ),
        'fa-android' => __( 'Android', 'flathost' ),
        'fa-angellist' => __( 'Angellist', 'flathost' ),
        'fa-angle-double-down' => __( 'Angle Double Down', 'flathost' ),
        'fa-angle-double-left' => __( 'Angle Double Left', 'flathost' ),
        'fa-angle-double-right' => __( 'Angle Double Right', 'flathost' ),
        'fa-angle-double-up' => __( 'Angle Double Up', 'flathost' ),
        'fa-angle-down' => __( 'Angle Down', 'flathost' ),
        'fa-angle-left' => __( 'Angle Left', 'flathost' ),
        'fa-angle-right' => __( 'Angle Right', 'flathost' ),
        'fa-angle-up' => __( 'Angle Up', 'flathost' ),
        'fa-apple' => __( 'Apple', 'flathost' ),
        'fa-archive' => __( 'Archive', 'flathost' ),
        'fa-area-chart' => __( 'Area Chart', 'flathost' ),
        'fa-arrow-circle-down' => __( 'Arrow Circle Down', 'flathost' ),
        'fa-arrow-circle-left' => __( 'Arrow Circle Left', 'flathost' ),
        'fa-arrow-circle-o-down' => __( 'Arrow Circle Outline Down', 'flathost' ),
        'fa-arrow-circle-o-left' => __( 'Arrow Circle Outline Left', 'flathost' ),
        'fa-arrow-circle-o-right' => __( 'Arrow Circle Outline Right', 'flathost' ),
        'fa-arrow-circle-o-up' => __( 'Arrow Circle Outline Up', 'flathost' ),
        'fa-arrow-circle-right' => __( 'Arrow Circle Right', 'flathost' ),
        'fa-arrow-circle-up' => __( 'Arrow Circle Up', 'flathost' ),
        'fa-arrow-down' => __( 'Arrow Down', 'flathost' ),
        'fa-arrow-left' => __( 'Arrow Left', 'flathost' ),
        'fa-arrow-right' => __( 'Arrow Right', 'flathost' ),
        'fa-arrow-up' => __( 'Arrow Up', 'flathost' ),
        'fa-arrows-alt' => __( 'Arrows Alt', 'flathost' ),
        'fa-arrows-h' => __( 'Arrows H', 'flathost' ),
        'fa-arrows-v' => __( 'Arrows V', 'flathost' ),
        'fa-arrows' => __( 'Arrows', 'flathost' ),
        'fa-asterisk' => __( 'Asterisk', 'flathost' ),
        'fa-at' => __( 'At', 'flathost' ),
        'fa-automobile' => __( 'Automobile', 'flathost' ),
        'fa-backward' => __( 'Backward', 'flathost' ),
        'fa-ban' => __( 'Ban', 'flathost' ),
        'fa-bank' => __( 'Bank', 'flathost' ),
        'fa-bar-chart-o' => __( 'Bar Chart Outline', 'flathost' ),
        'fa-bar-chart' => __( 'Bar Chart', 'flathost' ),
        'fa-barcode' => __( 'Barcode', 'flathost' ),
        'fa-bars' => __( 'Bars', 'flathost' ),
        'fa-beer' => __( 'Beer', 'flathost' ),
        'fa-behance-square' => __( 'Behance Square', 'flathost' ),
        'fa-behance' => __( 'Behance', 'flathost' ),
        'fa-bell-o' => __( 'Bell Outline', 'flathost' ),
        'fa-bell-slash-o' => __( 'Bell Slash Outline', 'flathost' ),
        'fa-bell-slash' => __( 'Bell Slash', 'flathost' ),
        'fa-bell' => __( 'Bell', 'flathost' ),
        'fa-bicycle' => __( 'Bicycle', 'flathost' ),
        'fa-binoculars' => __( 'Binoculars', 'flathost' ),
        'fa-birthday-cake' => __( 'Birthday Cake', 'flathost' ),
        'fa-bitbucket-square' => __( 'Bitbucket Square', 'flathost' ),
        'fa-bitbucket' => __( 'Bitbucket', 'flathost' ),
        'fa-bitcoin' => __( 'Bitcoin', 'flathost' ),
        'fa-bold' => __( 'Bold', 'flathost' ),
        'fa-bolt' => __( 'Bolt', 'flathost' ),
        'fa-bomb' => __( 'Bomb', 'flathost' ),
        'fa-book' => __( 'Book', 'flathost' ),
        'fa-bookmark-o' => __( 'Bookmark Outline', 'flathost' ),
        'fa-bookmark' => __( 'Bookmark', 'flathost' ),
        'fa-briefcase' => __( 'Briefcase', 'flathost' ),
        'fa-btc' => __( 'Btc', 'flathost' ),
        'fa-bug' => __( 'Bug', 'flathost' ),
        'fa-building-o' => __( 'Building Outline', 'flathost' ),
        'fa-building' => __( 'Building', 'flathost' ),
        'fa-bullhorn' => __( 'Bullhorn', 'flathost' ),
        'fa-bullseye' => __( 'Bullseye', 'flathost' ),
        'fa-bus' => __( 'Bus', 'flathost' ),
        'fa-cc-amex' => __( 'CC Amex', 'flathost' ),
        'fa-cc-discover' => __( 'CC Discover', 'flathost' ),
        'fa-cc-mastercard' => __( 'CC Mastercard', 'flathost' ),
        'fa-cc-paypal' => __( 'CC Paypal', 'flathost' ),
        'fa-cc-stripe' => __( 'CC Stripe', 'flathost' ),
        'fa-cc-visa' => __( 'CC Visa', 'flathost' ),
        'fa-cab' => __( 'Cab', 'flathost' ),
        'fa-calculator' => __( 'Calculator', 'flathost' ),
        'fa-calendar-o' => __( 'Calendar Outline', 'flathost' ),
        'fa-calendar' => __( 'Calendar', 'flathost' ),
        'fa-camera-retro' => __( 'Camera Retro', 'flathost' ),
        'fa-camera' => __( 'Camera', 'flathost' ),
        'fa-car' => __( 'Car', 'flathost' ),
        'fa-caret-down' => __( 'Caret Down', 'flathost' ),
        'fa-caret-left' => __( 'Caret Left', 'flathost' ),
        'fa-caret-right' => __( 'Caret Right', 'flathost' ),
        'fa-caret-square-o-down' => __( 'Caret Square Outline Down', 'flathost' ),
        'fa-caret-square-o-left' => __( 'Caret Square Outline Left', 'flathost' ),
        'fa-caret-square-o-right' => __( 'Caret Square Outline Right', 'flathost' ),
        'fa-caret-square-o-up' => __( 'Caret Square Outline Up', 'flathost' ),
        'fa-caret-up' => __( 'Caret Up', 'flathost' ),
        'fa-cc' => __( 'Cc', 'flathost' ),
        'fa-certificate' => __( 'Certificate', 'flathost' ),
        'fa-chain-broken' => __( 'Chain Broken', 'flathost' ),
        'fa-chain' => __( 'Chain', 'flathost' ),
        'fa-check-circle-o' => __( 'Check Circle Outline', 'flathost' ),
        'fa-check-circle' => __( 'Check Circle', 'flathost' ),
        'fa-check-square-o' => __( 'Check Square Outline', 'flathost' ),
        'fa-check-square' => __( 'Check Square', 'flathost' ),
        'fa-check' => __( 'Check', 'flathost' ),
        'fa-chevron-circle-down' => __( 'Chevron Circle Down', 'flathost' ),
        'fa-chevron-circle-left' => __( 'Chevron Circle Left', 'flathost' ),
        'fa-chevron-circle-right' => __( 'Chevron Circle Right', 'flathost' ),
        'fa-chevron-circle-up' => __( 'Chevron Circle Up', 'flathost' ),
        'fa-chevron-down' => __( 'Chevron Down', 'flathost' ),
        'fa-chevron-left' => __( 'Chevron Left', 'flathost' ),
        'fa-chevron-right' => __( 'Chevron Right', 'flathost' ),
        'fa-chevron-up' => __( 'Chevron Up', 'flathost' ),
        'fa-child' => __( 'Child', 'flathost' ),
        'fa-circle-o-notch' => __( 'Circle Outline Notch', 'flathost' ),
        'fa-circle-o' => __( 'Circle Outline', 'flathost' ),
        'fa-circle-thin' => __( 'Circle Thin', 'flathost' ),
        'fa-circle' => __( 'Circle', 'flathost' ),
        'fa-clipboard' => __( 'Clipboard', 'flathost' ),
        'fa-clock-o' => __( 'Clock Outline', 'flathost' ),
        'fa-close' => __( 'Close', 'flathost' ),
        'fa-cloud-download' => __( 'Cloud Download', 'flathost' ),
        'fa-cloud-upload' => __( 'Cloud Upload', 'flathost' ),
        'fa-cloud' => __( 'Cloud', 'flathost' ),
        'fa-cny' => __( 'Cny', 'flathost' ),
        'fa-code-fork' => __( 'Code Fork', 'flathost' ),
        'fa-code' => __( 'Code', 'flathost' ),
        'fa-codepen' => __( 'Codepen', 'flathost' ),
        'fa-coffee' => __( 'Coffee', 'flathost' ),
        'fa-cog' => __( 'Cog', 'flathost' ),
        'fa-cogs' => __( 'Cogs', 'flathost' ),
        'fa-columns' => __( 'Columns', 'flathost' ),
        'fa-comment-o' => __( 'Comment Outline', 'flathost' ),
        'fa-comment' => __( 'Comment', 'flathost' ),
        'fa-comments-o' => __( 'Comments Outline', 'flathost' ),
        'fa-comments' => __( 'Comments', 'flathost' ),
        'fa-compass' => __( 'Compass', 'flathost' ),
        'fa-compress' => __( 'Compress', 'flathost' ),
        'fa-copy' => __( 'Copy', 'flathost' ),
        'fa-copyright' => __( 'Copyright', 'flathost' ),
        'fa-credit-card' => __( 'Credit Card', 'flathost' ),
        'fa-crop' => __( 'Crop', 'flathost' ),
        'fa-crosshairs' => __( 'Crosshairs', 'flathost' ),
        'fa-css3' => __( 'Css3', 'flathost' ),
        'fa-cube' => __( 'Cube', 'flathost' ),
        'fa-cubes' => __( 'Cubes', 'flathost' ),
        'fa-cut' => __( 'Cut', 'flathost' ),
        'fa-cutlery' => __( 'Cutlery', 'flathost' ),
        'fa-dashboard' => __( 'Dashboard', 'flathost' ),
        'fa-database' => __( 'Database', 'flathost' ),
        'fa-dedent' => __( 'Dedent', 'flathost' ),
        'fa-delicious' => __( 'Delicious', 'flathost' ),
        'fa-desktop' => __( 'Desktop', 'flathost' ),
        'fa-deviantart' => __( 'Deviantart', 'flathost' ),
        'fa-digg' => __( 'Digg', 'flathost' ),
        'fa-dollar' => __( 'Dollar', 'flathost' ),
        'fa-dot-circle-o' => __( 'Dot Circle Outline', 'flathost' ),
        'fa-download' => __( 'Download', 'flathost' ),
        'fa-dribbble' => __( 'Dribbble', 'flathost' ),
        'fa-dropbox' => __( 'Dropbox', 'flathost' ),
        'fa-drupal' => __( 'Drupal', 'flathost' ),
        'fa-edit' => __( 'Edit', 'flathost' ),
        'fa-eject' => __( 'Eject', 'flathost' ),
        'fa-ellipsis-h' => __( 'Ellipsis H', 'flathost' ),
        'fa-ellipsis-v' => __( 'Ellipsis V', 'flathost' ),
        'fa-empire' => __( 'Empire', 'flathost' ),
        'fa-envelope-o' => __( 'Envelope Outline', 'flathost' ),
        'fa-envelope-square' => __( 'Envelope Square', 'flathost' ),
        'fa-envelope' => __( 'Envelope', 'flathost' ),
        'fa-eraser' => __( 'Eraser', 'flathost' ),
        'fa-eur' => __( 'Eur', 'flathost' ),
        'fa-euro' => __( 'Euro', 'flathost' ),
        'fa-exchange' => __( 'Exchange', 'flathost' ),
        'fa-exclamation-circle' => __( 'Exclamation Circle', 'flathost' ),
        'fa-exclamation-triangle' => __( 'Exclamation Triangle', 'flathost' ),
        'fa-exclamation' => __( 'Exclamation', 'flathost' ),
        'fa-expand' => __( 'Expand', 'flathost' ),
        'fa-external-link-square' => __( 'External Link Square', 'flathost' ),
        'fa-external-link' => __( 'External Link', 'flathost' ),
        'fa-eye-slash' => __( 'Eye Slash', 'flathost' ),
        'fa-eye' => __( 'Eye', 'flathost' ),
        'fa-eyedropper' => __( 'Eyedropper', 'flathost' ),
        'fa-facebook-square' => __( 'Facebook Square', 'flathost' ),
        'fa-facebook' => __( 'Facebook', 'flathost' ),
        'fa-fast-backward' => __( 'Fast Backward', 'flathost' ),
        'fa-fast-forward' => __( 'Fast Forward', 'flathost' ),
        'fa-fax' => __( 'Fax', 'flathost' ),
        'fa-female' => __( 'Female', 'flathost' ),
        'fa-fighter-jet' => __( 'Fighter Jet', 'flathost' ),
        'fa-file-archive-o' => __( 'File Archive Outline', 'flathost' ),
        'fa-file-audio-o' => __( 'File Audio Outline', 'flathost' ),
        'fa-file-code-o' => __( 'File Code Outline', 'flathost' ),
        'fa-file-excel-o' => __( 'File Excel Outline', 'flathost' ),
        'fa-file-image-o' => __( 'File Image Outline', 'flathost' ),
        'fa-file-movie-o' => __( 'File Movie Outline', 'flathost' ),
        'fa-file-o' => __( 'File Outline', 'flathost' ),
        'fa-file-pdf-o' => __( 'File Pdf Outline', 'flathost' ),
        'fa-file-photo-o' => __( 'File Photo Outline', 'flathost' ),
        'fa-file-picture-o' => __( 'File Picture Outline', 'flathost' ),
        'fa-file-powerpoint-o' => __( 'File Powerpoint Outline', 'flathost' ),
        'fa-file-sound-o' => __( 'File Sound Outline', 'flathost' ),
        'fa-file-text-o' => __( 'File Text Outline', 'flathost' ),
        'fa-file-text' => __( 'File Text', 'flathost' ),
        'fa-file-video-o' => __( 'File Video Outline', 'flathost' ),
        'fa-file-word-o' => __( 'File Word Outline', 'flathost' ),
        'fa-file-zip-o' => __( 'File Zip Outline', 'flathost' ),
        'fa-file' => __( 'File', 'flathost' ),
        'fa-files-o' => __( 'Files Outline', 'flathost' ),
        'fa-film' => __( 'Film', 'flathost' ),
        'fa-filter' => __( 'Filter', 'flathost' ),
        'fa-fire-extinguisher' => __( 'Fire Extinguisher', 'flathost' ),
        'fa-fire' => __( 'Fire', 'flathost' ),
        'fa-flag-checkered' => __( 'Flag Checkered', 'flathost' ),
        'fa-flag-o' => __( 'Flag Outline', 'flathost' ),
        'fa-flag' => __( 'Flag', 'flathost' ),
        'fa-flash' => __( 'Flash', 'flathost' ),
        'fa-flask' => __( 'Flask', 'flathost' ),
        'fa-flickr' => __( 'Flickr', 'flathost' ),
        'fa-floppy-o' => __( 'Floppy Outline', 'flathost' ),
        'fa-folder-o' => __( 'Folder Outline', 'flathost' ),
        'fa-folder-open-o' => __( 'Folder Outlinepen Outline', 'flathost' ),
        'fa-folder-open' => __( 'Folder Outlinepen', 'flathost' ),
        'fa-folder' => __( 'Folder', 'flathost' ),
        'fa-font' => __( 'Font', 'flathost' ),
        'fa-forward' => __( 'Forward', 'flathost' ),
        'fa-foursquare' => __( 'Foursquare', 'flathost' ),
        'fa-frown-o' => __( 'Frown Outline', 'flathost' ),
        'fa-futbol-o' => __( 'Futbol Outline', 'flathost' ),
        'fa-gamepad' => __( 'Gamepad', 'flathost' ),
        'fa-gavel' => __( 'Gavel', 'flathost' ),
        'fa-gbp' => __( 'Gbp', 'flathost' ),
        'fa-ge' => __( 'Ge', 'flathost' ),
        'fa-gear' => __( 'Gear', 'flathost' ),
        'fa-gears' => __( 'Gears', 'flathost' ),
        'fa-gift' => __( 'Gift', 'flathost' ),
        'fa-git-square' => __( 'Git Square', 'flathost' ),
        'fa-git' => __( 'Git', 'flathost' ),
        'fa-github-alt' => __( 'Github Alt', 'flathost' ),
        'fa-github-square' => __( 'Github Square', 'flathost' ),
        'fa-github' => __( 'Github', 'flathost' ),
        'fa-gittip' => __( 'Gittip', 'flathost' ),
        'fa-glass' => __( 'Glass', 'flathost' ),
        'fa-globe' => __( 'Globe', 'flathost' ),
        'fa-google-plus-square' => __( 'Google Plus Square', 'flathost' ),
        'fa-google-plus' => __( 'Google Plus', 'flathost' ),
        'fa-google-wallet' => __( 'Google Wallet', 'flathost' ),
        'fa-google' => __( 'Google', 'flathost' ),
        'fa-graduation-cap' => __( 'Graduation Cap', 'flathost' ),
        'fa-group' => __( 'Group', 'flathost' ),
        'fa-h-square' => __( 'H Square', 'flathost' ),
        'fa-hacker-news' => __( 'Hacker News', 'flathost' ),
        'fa-hand-o-down' => __( 'Hand Outline Down', 'flathost' ),
        'fa-hand-o-left' => __( 'Hand Outline Left', 'flathost' ),
        'fa-hand-o-right' => __( 'Hand Outline Right', 'flathost' ),
        'fa-hand-o-up' => __( 'Hand Outline Up', 'flathost' ),
        'fa-hdd-o' => __( 'Hdd Outline', 'flathost' ),
        'fa-header' => __( 'Header', 'flathost' ),
        'fa-headphones' => __( 'Headphones', 'flathost' ),
        'fa-heart-o' => __( 'Heart Outline', 'flathost' ),
        'fa-heart' => __( 'Heart', 'flathost' ),
        'fa-history' => __( 'History', 'flathost' ),
        'fa-home' => __( 'Home', 'flathost' ),
        'fa-hospital-o' => __( 'Hospital Outline', 'flathost' ),
        'fa-html5' => __( 'Html5', 'flathost' ),
        'fa-ils' => __( 'Ils', 'flathost' ),
        'fa-image' => __( 'Image', 'flathost' ),
        'fa-inbox' => __( 'Inbox', 'flathost' ),
        'fa-indent' => __( 'Indent', 'flathost' ),
        'fa-info-circle' => __( 'Info Circle', 'flathost' ),
        'fa-info' => __( 'Info', 'flathost' ),
        'fa-inr' => __( 'Inr', 'flathost' ),
        'fa-instagram' => __( 'Instagram', 'flathost' ),
        'fa-institution' => __( 'Institution', 'flathost' ),
        'fa-ioxhost' => __( 'Ioxhost', 'flathost' ),
        'fa-italic' => __( 'Italic', 'flathost' ),
        'fa-joomla' => __( 'Joomla', 'flathost' ),
        'fa-jpy' => __( 'Jpy', 'flathost' ),
        'fa-jsfiddle' => __( 'Jsfiddle', 'flathost' ),
        'fa-key' => __( 'Key', 'flathost' ),
        'fa-keyboard-o' => __( 'Keyboard Outline', 'flathost' ),
        'fa-krw' => __( 'Krw', 'flathost' ),
        'fa-language' => __( 'Language', 'flathost' ),
        'fa-laptop' => __( 'Laptop', 'flathost' ),
        'fa-lastfm-square' => __( 'Lastfm Square', 'flathost' ),
        'fa-lastfm' => __( 'Lastfm', 'flathost' ),
        'fa-leaf' => __( 'Leaf', 'flathost' ),
        'fa-legal' => __( 'Legal', 'flathost' ),
        'fa-lemon-o' => __( 'Lemon Outline', 'flathost' ),
        'fa-level-down' => __( 'Level Down', 'flathost' ),
        'fa-level-up' => __( 'Level Up', 'flathost' ),
        'fa-life-bouy' => __( 'Life Bouy', 'flathost' ),
        'fa-life-buoy' => __( 'Life Buoy', 'flathost' ),
        'fa-life-ring' => __( 'Life Ring', 'flathost' ),
        'fa-life-saver' => __( 'Life Saver', 'flathost' ),
        'fa-lightbulb-o' => __( 'Lightbulb Outline', 'flathost' ),
        'fa-line-chart' => __( 'Line Chart', 'flathost' ),
        'fa-link' => __( 'Link', 'flathost' ),
        'fa-linkedin-square' => __( 'Linkedin Square', 'flathost' ),
        'fa-linkedin' => __( 'Linkedin', 'flathost' ),
        'fa-linux' => __( 'Linux', 'flathost' ),
        'fa-list-alt' => __( 'List Alt', 'flathost' ),
        'fa-list-ol' => __( 'List Outlinel', 'flathost' ),
        'fa-list-ul' => __( 'List Ul', 'flathost' ),
        'fa-list' => __( 'List', 'flathost' ),
        'fa-location-arrow' => __( 'Location Arrow', 'flathost' ),
        'fa-lock' => __( 'Lock', 'flathost' ),
        'fa-long-arrow-down' => __( 'Long Arrow Down', 'flathost' ),
        'fa-long-arrow-left' => __( 'Long Arrow Left', 'flathost' ),
        'fa-long-arrow-right' => __( 'Long Arrow Right', 'flathost' ),
        'fa-long-arrow-up' => __( 'Long Arrow Up', 'flathost' ),
        'fa-magic' => __( 'Magic', 'flathost' ),
        'fa-magnet' => __( 'Magnet', 'flathost' ),
        'fa-mail-forward' => __( 'Mail Forward', 'flathost' ),
        'fa-mail-reply-all' => __( 'Mail Reply All', 'flathost' ),
        'fa-mail-reply' => __( 'Mail Reply', 'flathost' ),
        'fa-male' => __( 'Male', 'flathost' ),
        'fa-map-marker' => __( 'Map Marker', 'flathost' ),
        'fa-maxcdn' => __( 'Maxcdn', 'flathost' ),
        'fa-meanpath' => __( 'Meanpath', 'flathost' ),
        'fa-medkit' => __( 'Medkit', 'flathost' ),
        'fa-meh-o' => __( 'Meh Outline', 'flathost' ),
        'fa-microphone-slash' => __( 'Microphone Slash', 'flathost' ),
        'fa-microphone' => __( 'Microphone', 'flathost' ),
        'fa-minus-circle' => __( 'Minus Circle', 'flathost' ),
        'fa-minus-square-o' => __( 'Minus Square Outline', 'flathost' ),
        'fa-minus-square' => __( 'Minus Square', 'flathost' ),
        'fa-minus' => __( 'Minus', 'flathost' ),
        'fa-mobile-phone' => __( 'Mobile Phone', 'flathost' ),
        'fa-mobile' => __( 'Mobile', 'flathost' ),
        'fa-money' => __( 'Money', 'flathost' ),
        'fa-moon-o' => __( 'Moon Outline', 'flathost' ),
        'fa-mortar-board' => __( 'Mortar Board', 'flathost' ),
        'fa-music' => __( 'Music', 'flathost' ),
        'fa-navicon' => __( 'Navicon', 'flathost' ),
        'fa-newspaper-o' => __( 'Newspaper Outline', 'flathost' ),
        'fa-openid' => __( 'Openid', 'flathost' ),
        'fa-outdent' => __( 'Outdent', 'flathost' ),
        'fa-pagelines' => __( 'Pagelines', 'flathost' ),
        'fa-paint-brush' => __( 'Paint Brush', 'flathost' ),
        'fa-paper-plane-o' => __( 'Paper Plane Outline', 'flathost' ),
        'fa-paper-plane' => __( 'Paper Plane', 'flathost' ),
        'fa-paperclip' => __( 'Paperclip', 'flathost' ),
        'fa-paragraph' => __( 'Paragraph', 'flathost' ),
        'fa-paste' => __( 'Paste', 'flathost' ),
        'fa-pause' => __( 'Pause', 'flathost' ),
        'fa-paw' => __( 'Paw', 'flathost' ),
        'fa-paypal' => __( 'Paypal', 'flathost' ),
        'fa-pencil-square-o' => __( 'Pencil Square Outline', 'flathost' ),
        'fa-pencil-square' => __( 'Pencil Square', 'flathost' ),
        'fa-pencil' => __( 'Pencil', 'flathost' ),
        'fa-phone-square' => __( 'Phone Square', 'flathost' ),
        'fa-phone' => __( 'Phone', 'flathost' ),
        'fa-photo' => __( 'Photo', 'flathost' ),
        'fa-picture-o' => __( 'Picture Outline', 'flathost' ),
        'fa-pie-chart' => __( 'Pie Chart', 'flathost' ),
        'fa-pied-piper-alt' => __( 'Pied Piper Alt', 'flathost' ),
        'fa-pied-piper' => __( 'Pied Piper', 'flathost' ),
        'fa-pinterest-square' => __( 'Pinterest Square', 'flathost' ),
        'fa-pinterest' => __( 'Pinterest', 'flathost' ),
        'fa-plane' => __( 'Plane', 'flathost' ),
        'fa-play-circle-o' => __( 'Play Circle Outline', 'flathost' ),
        'fa-play-circle' => __( 'Play Circle', 'flathost' ),
        'fa-play' => __( 'Play', 'flathost' ),
        'fa-plug' => __( 'Plug', 'flathost' ),
        'fa-plus-circle' => __( 'Plus Circle', 'flathost' ),
        'fa-plus-square-o' => __( 'Plus Square Outline', 'flathost' ),
        'fa-plus-square' => __( 'Plus Square', 'flathost' ),
        'fa-plus' => __( 'Plus', 'flathost' ),
        'fa-power-off' => __( 'Power Outlineff', 'flathost' ),
        'fa-print' => __( 'Print', 'flathost' ),
        'fa-puzzle-piece' => __( 'Puzzle Piece', 'flathost' ),
        'fa-qq' => __( 'Qq', 'flathost' ),
        'fa-qrcode' => __( 'Qrcode', 'flathost' ),
        'fa-question-circle' => __( 'Question Circle', 'flathost' ),
        'fa-question' => __( 'Question', 'flathost' ),
        'fa-quote-left' => __( 'Quote Left', 'flathost' ),
        'fa-quote-right' => __( 'Quote Right', 'flathost' ),
        'fa-ra' => __( 'Ra', 'flathost' ),
        'fa-random' => __( 'Random', 'flathost' ),
        'fa-rebel' => __( 'Rebel', 'flathost' ),
        'fa-recycle' => __( 'Recycle', 'flathost' ),
        'fa-reddit-square' => __( 'Reddit Square', 'flathost' ),
        'fa-reddit' => __( 'Reddit', 'flathost' ),
        'fa-refresh' => __( 'Refresh', 'flathost' ),
        'fa-remove' => __( 'Remove', 'flathost' ),
        'fa-renren' => __( 'Renren', 'flathost' ),
        'fa-reorder' => __( 'Reorder', 'flathost' ),
        'fa-repeat' => __( 'Repeat', 'flathost' ),
        'fa-reply-all' => __( 'Reply All', 'flathost' ),
        'fa-reply' => __( 'Reply', 'flathost' ),
        'fa-retweet' => __( 'Retweet', 'flathost' ),
        'fa-rmb' => __( 'Rmb', 'flathost' ),
        'fa-road' => __( 'Road', 'flathost' ),
        'fa-rocket' => __( 'Rocket', 'flathost' ),
        'fa-rotate-left' => __( 'Rotate Left', 'flathost' ),
        'fa-rotate-right' => __( 'Rotate Right', 'flathost' ),
        'fa-rouble' => __( 'Rouble', 'flathost' ),
        'fa-rss-square' => __( 'Rss Square', 'flathost' ),
        'fa-rss' => __( 'Rss', 'flathost' ),
        'fa-rub' => __( 'Rub', 'flathost' ),
        'fa-ruble' => __( 'Ruble', 'flathost' ),
        'fa-rupee' => __( 'Rupee', 'flathost' ),
        'fa-save' => __( 'Save', 'flathost' ),
        'fa-scissors' => __( 'Scissors', 'flathost' ),
        'fa-search-minus' => __( 'Search Minus', 'flathost' ),
        'fa-search-plus' => __( 'Search Plus', 'flathost' ),
        'fa-search' => __( 'Search', 'flathost' ),
        'fa-send-o' => __( 'Send Outline', 'flathost' ),
        'fa-send' => __( 'Send', 'flathost' ),
        'fa-share-alt-square' => __( 'Share Alt Square', 'flathost' ),
        'fa-share-alt' => __( 'Share Alt', 'flathost' ),
        'fa-share-square-o' => __( 'Share Square Outline', 'flathost' ),
        'fa-share-square' => __( 'Share Square', 'flathost' ),
        'fa-share' => __( 'Share', 'flathost' ),
        'fa-shekel' => __( 'Shekel', 'flathost' ),
        'fa-sheqel' => __( 'Sheqel', 'flathost' ),
        'fa-shield' => __( 'Shield', 'flathost' ),
        'fa-shopping-cart' => __( 'Shopping Cart', 'flathost' ),
        'fa-sign-in' => __( 'Sign In', 'flathost' ),
        'fa-sign-out' => __( 'Sign Outlineut', 'flathost' ),
        'fa-signal' => __( 'Signal', 'flathost' ),
        'fa-sitemap' => __( 'Sitemap', 'flathost' ),
        'fa-skype' => __( 'Skype', 'flathost' ),
        'fa-slack' => __( 'Slack', 'flathost' ),
        'fa-sliders' => __( 'Sliders', 'flathost' ),
        'fa-slideshare' => __( 'Slideshare', 'flathost' ),
        'fa-smile-o' => __( 'Smile Outline', 'flathost' ),
        'fa-soccer-ball-o' => __( 'Soccer Ball Outline', 'flathost' ),
        'fa-sort-alpha-asc' => __( 'Sort Alpha Asc', 'flathost' ),
        'fa-sort-alpha-desc' => __( 'Sort Alpha Desc', 'flathost' ),
        'fa-sort-amount-asc' => __( 'Sort Amount Asc', 'flathost' ),
        'fa-sort-amount-desc' => __( 'Sort Amount Desc', 'flathost' ),
        'fa-sort-asc' => __( 'Sort Asc', 'flathost' ),
        'fa-sort-desc' => __( 'Sort Desc', 'flathost' ),
        'fa-sort-down' => __( 'Sort Down', 'flathost' ),
        'fa-sort-numeric-asc' => __( 'Sort Numeric Asc', 'flathost' ),
        'fa-sort-numeric-desc' => __( 'Sort Numeric Desc', 'flathost' ),
        'fa-sort-up' => __( 'Sort Up', 'flathost' ),
        'fa-sort' => __( 'Sort', 'flathost' ),
        'fa-soundcloud' => __( 'Soundcloud', 'flathost' ),
        'fa-space-shuttle' => __( 'Space Shuttle', 'flathost' ),
        'fa-spinner' => __( 'Spinner', 'flathost' ),
        'fa-spoon' => __( 'Spoon', 'flathost' ),
        'fa-spotify' => __( 'Spotify', 'flathost' ),
        'fa-square-o' => __( 'Square Outline', 'flathost' ),
        'fa-square' => __( 'Square', 'flathost' ),
        'fa-stack-exchange' => __( 'Stack Exchange', 'flathost' ),
        'fa-stack-overflow' => __( 'Stack Outlineverflow', 'flathost' ),
        'fa-star-half-empty' => __( 'Star Half Empty', 'flathost' ),
        'fa-star-half-full' => __( 'Star Half Full', 'flathost' ),
        'fa-star-half-o' => __( 'Star Half Outline', 'flathost' ),
        'fa-star-half' => __( 'Star Half', 'flathost' ),
        'fa-star-o' => __( 'Star Outline', 'flathost' ),
        'fa-star' => __( 'Star', 'flathost' ),
        'fa-steam-square' => __( 'Steam Square', 'flathost' ),
        'fa-steam' => __( 'Steam', 'flathost' ),
        'fa-step-backward' => __( 'Step Backward', 'flathost' ),
        'fa-step-forward' => __( 'Step Forward', 'flathost' ),
        'fa-stethoscope' => __( 'Stethoscope', 'flathost' ),
        'fa-stop' => __( 'Stop', 'flathost' ),
        'fa-strikethrough' => __( 'Strikethrough', 'flathost' ),
        'fa-stumbleupon-circle' => __( 'Stumbleupon Circle', 'flathost' ),
        'fa-stumbleupon' => __( 'Stumbleupon', 'flathost' ),
        'fa-subscript' => __( 'Subscript', 'flathost' ),
        'fa-suitcase' => __( 'Suitcase', 'flathost' ),
        'fa-sun-o' => __( 'Sun Outline', 'flathost' ),
        'fa-superscript' => __( 'Superscript', 'flathost' ),
        'fa-support' => __( 'Support', 'flathost' ),
        'fa-table' => __( 'Table', 'flathost' ),
        'fa-tablet' => __( 'Tablet', 'flathost' ),
        'fa-tachometer' => __( 'Tachometer', 'flathost' ),
        'fa-tag' => __( 'Tag', 'flathost' ),
        'fa-tags' => __( 'Tags', 'flathost' ),
        'fa-tasks' => __( 'Tasks', 'flathost' ),
        'fa-taxi' => __( 'Taxi', 'flathost' ),
        'fa-tencent-weibo' => __( 'Tencent Weibo', 'flathost' ),
        'fa-terminal' => __( 'Terminal', 'flathost' ),
        'fa-text-height' => __( 'Text Height', 'flathost' ),
        'fa-text-width' => __( 'Text Width', 'flathost' ),
        'fa-th-large' => __( 'Th Large', 'flathost' ),
        'fa-th-list' => __( 'Th List', 'flathost' ),
        'fa-th' => __( 'Th', 'flathost' ),
        'fa-thumb-tack' => __( 'Thumb Tack', 'flathost' ),
        'fa-thumbs-down' => __( 'Thumbs Down', 'flathost' ),
        'fa-thumbs-o-down' => __( 'Thumbs Outline Down', 'flathost' ),
        'fa-thumbs-o-up' => __( 'Thumbs Outline Up', 'flathost' ),
        'fa-thumbs-up' => __( 'Thumbs Up', 'flathost' ),
        'fa-ticket' => __( 'Ticket', 'flathost' ),
        'fa-times-circle-o' => __( 'Times Circle Outline', 'flathost' ),
        'fa-times-circle' => __( 'Times Circle', 'flathost' ),
        'fa-times' => __( 'Times', 'flathost' ),
        'fa-tint' => __( 'Tint', 'flathost' ),
        'fa-toggle-down' => __( 'Toggle Down', 'flathost' ),
        'fa-toggle-left' => __( 'Toggle Left', 'flathost' ),
        'fa-toggle-off' => __( 'Toggle Outlineff', 'flathost' ),
        'fa-toggle-on' => __( 'Toggle Outlinen', 'flathost' ),
        'fa-toggle-right' => __( 'Toggle Right', 'flathost' ),
        'fa-toggle-up' => __( 'Toggle Up', 'flathost' ),
        'fa-trash-o' => __( 'Trash Outline', 'flathost' ),
        'fa-trash' => __( 'Trash', 'flathost' ),
        'fa-tree' => __( 'Tree', 'flathost' ),
        'fa-trello' => __( 'Trello', 'flathost' ),
        'fa-trophy' => __( 'Trophy', 'flathost' ),
        'fa-truck' => __( 'Truck', 'flathost' ),
        'fa-try' => __( 'Try', 'flathost' ),
        'fa-tty' => __( 'Tty', 'flathost' ),
        'fa-tumblr-square' => __( 'Tumblr Square', 'flathost' ),
        'fa-tumblr' => __( 'Tumblr', 'flathost' ),
        'fa-turkish-lira' => __( 'Turkish Lira', 'flathost' ),
        'fa-twitch' => __( 'Twitch', 'flathost' ),
        'fa-twitter-square' => __( 'Twitter Square', 'flathost' ),
        'fa-twitter' => __( 'Twitter', 'flathost' ),
        'fa-umbrella' => __( 'Umbrella', 'flathost' ),
        'fa-underline' => __( 'Underline', 'flathost' ),
        'fa-undo' => __( 'Undo', 'flathost' ),
        'fa-university' => __( 'University', 'flathost' ),
        'fa-unlink' => __( 'Unlink', 'flathost' ),
        'fa-unlock-alt' => __( 'Unlock Alt', 'flathost' ),
        'fa-unlock' => __( 'Unlock', 'flathost' ),
        'fa-unsorted' => __( 'Unsorted', 'flathost' ),
        'fa-upload' => __( 'Upload', 'flathost' ),
        'fa-usd' => __( 'Usd', 'flathost' ),
        'fa-user-md' => __( 'User Md', 'flathost' ),
        'fa-user' => __( 'User', 'flathost' ),
        'fa-users' => __( 'Users', 'flathost' ),
        'fa-video-camera' => __( 'Video Camera', 'flathost' ),
        'fa-vimeo-square' => __( 'Vimeo Square', 'flathost' ),
        'fa-vine' => __( 'Vine', 'flathost' ),
        'fa-vk' => __( 'Vk', 'flathost' ),
        'fa-volume-down' => __( 'Volume Down', 'flathost' ),
        'fa-volume-off' => __( 'Volume Outlineff', 'flathost' ),
        'fa-volume-up' => __( 'Volume Up', 'flathost' ),
        'fa-warning' => __( 'Warning', 'flathost' ),
        'fa-wechat' => __( 'Wechat', 'flathost' ),
        'fa-weibo' => __( 'Weibo', 'flathost' ),
        'fa-weixin' => __( 'Weixin', 'flathost' ),
        'fa-wheelchair' => __( 'Wheelchair', 'flathost' ),
        'fa-wifi' => __( 'Wifi', 'flathost' ),
        'fa-windows' => __( 'Windows', 'flathost' ),
        'fa-won' => __( 'Won', 'flathost' ),
        'fa-wordpress' => __( 'Wordpress', 'flathost' ),
        'fa-wrench' => __( 'Wrench', 'flathost' ),
        'fa-xing-square' => __( 'Xing Square', 'flathost' ),
        'fa-xing' => __( 'Xing', 'flathost' ),
        'fa-yahoo' => __( 'Yahoo', 'flathost' ),
        'fa-yelp' => __( 'Yelp', 'flathost' ),
        'fa-yen' => __( 'Yen', 'flathost' ),
        'fa-youtube-play' => __( 'Youtube Play', 'flathost' ),
        'fa-youtube-square' => __( 'Youtube Square', 'flathost' ),
        'fa-youtube' => __( 'Youtube', 'flathost' )
     );
}