<?php



/**

 * Init Theme Related Settings

 */



/** Internal Settings **/

require_once 'version.php';



/**

 * Required and Recommended Plugins

 */

function spyropress_register_plugins() {



    /**

     * Array of plugin arrays. Required keys are name and slug.

     * If the source is NOT from the .org repo, then source is also required.

     */

    $plugins = array(
 
        // Contact Form 7

        array(
            'name'      => esc_html__('Contact Form 7','flathost'),
            'slug'      => 'contact-form-7',
            'required'  => false,
        ),
        
        // Envato Toolkit Master
        array(
            'name'      => esc_html__('Zopim Live Chat','flathost'),
            'slug'      => 'zopim-live-chat',
            'required'  => false,
        ),

        array(
            'name'      => esc_html__('WHMCS Bridge','flathost'),
            'slug'      => 'whmcs-bridge',
            'required'  => false,
        ),
        //Revolution slider
        array(
            'name'      => esc_html__('Revolution Slider','flathost'),
            'slug'      => 'revslider',
            'required'  => true,
            'source'    => get_template_directory() . '/includes/plugins/revslider.zip'
        ),
         array(
            'name'      => esc_html__('CMS SpyroPress','flathost'),
            'slug'      => 'cms-spyropress',
            'required'  => true,
            'source'    => get_template_directory() . '/includes/plugins/cms-spyropress.zip'
        ),
        
        array(
            'name'               => esc_html__('Ef3 Import and Export','flathost'),
            'slug'               => 'ef3-import-and-export',
            'source'             => esc_url('http://spyropress.com/plugins/ef3-import-and-export.zip'),
            'required'           => false,
        ),
    );

    $config = array(
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
    );

    tgmpa( $plugins, $config );

}

add_action( 'tgmpa_register', 'spyropress_register_plugins' );



/**

 * Add modules and tempaltes to SpyroBuilder

 */

function spyropress_register_builder_modules( $modules ) {



    $path = dirname(__FILE__);



    $modules[] = 'modules/icon-teaser/icon-teaser.php';

    $modules[] = 'modules/our-clients/clients.php';

    $modules[] = 'modules/heading/heading.php';

    $modules[] = 'modules/list/list.php';

    $modules[] = 'modules/divider/divider.php';

    $modules[] = 'modules/testimonials/testimonials.php';

    $modules[] = 'modules/gmap/gmap.php';
    
    $modules[] = 'modules/domain/domain.php';
    
    $modules[] = 'modules/domain-register/domain-register.php';



    return $modules;

}

add_filter( 'builder_include_modules', 'spyropress_register_builder_modules' );



/**

 * Define the row wrapper html

 */

function spyropress_row_wrapper( $row_ID, $row ) {

    

    // CssClass

    $section_class = array();

    if( isset( $row['options']['skin'] ) && !empty( $row['options']['skin'] ) )

        $section_class[] = $row['options']['skin'];



    $row_html = sprintf( '

        <div id="%1$s" class="%2$s">

            <div class="container">

                <div class="%3$s">

                    %4$s

                </div>

            </div>

        </div>', $row_ID, spyropress_clean_cssclass( $section_class ), get_row_class( true ), builder_render_frontend_columns( $row['columns'] )

    );



    return $row_html;

}

add_filter( 'spyropress_builder_row_wrapper', 'spyropress_row_wrapper', 10, 2 );



/**

 * Include Widgets

 */

function spyropress_register_widgets( $widgets ) {

    

    $path = dirname(__FILE__) . '/widgets/';



    $custom = array(

         $path . 'contact-info/contact.php'

    );



    return array_merge( $widgets, $custom );

}

add_filter( 'spyropress_register_widgets', 'spyropress_register_widgets' );



/**

 * Unregister Widgets

 */

function spyropress_unregister_widgets( $widgets ) {

    

    $custom = array();



    return array_merge( $widgets, $custom );

}

add_filter( 'spyropress_unregister_widgets', 'spyropress_unregister_widgets' );



/**

 * Comment Callback

 */

if( !function_exists( 'spyropress_comment' ) ) :

function spyropress_comment( $comment, $args, $depth ) {

    $GLOBALS['comment'] = $comment;
    extract($args, EXTR_SKIP);

    if ( 'div' == $args['style'] ) {
        $tag = 'div';
        $add_below = 'comment';
    } else {
        $tag = 'li';
        $add_below = 'div-comment';
    }
    ?>
    <<?php echo esc_attr($tag) ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
    <div id="div-comment-<?php comment_ID() ?>" class="comment-body clearfix">
    <?php endif; ?>
    <div class="comment-author-image vcard">
        <?php echo get_avatar( $comment, 70 ); ?>
    </div>
    
    <div class="comment-main">
    
        <div class="comment-meta commentmetadata">
            <?php
            echo '<h5 class="comment-author">'. get_comment_author_link() .'<span class="comment-date">';
                 $comment_date = get_comment_date('F j, Y',get_comment_ID()); 
                      echo esc_attr($comment_date);  
            echo '</span></h5>';
            ?>
            <div class="comment-reply">
              <?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
            </div>  
        </div>
        
        <div class="comment-content">
            <?php comment_text(); ?>
        </div>
        <?php if ( $comment->comment_approved == '0' ) : ?>
            <em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.' , 'flathost'); ?></em>
        <?php endif; ?>
    </div>

    <?php if ( 'div' != $args['style'] ) : ?>
    </div>
    <?php endif; ?>
    <?php

}

endif;



/**

 * Pagination Defaults

 */

function spyropress_pagination_defaults( $defaults = array() ) {

    

    $defaults['container'] = 'nav';

    $defaults['style'] = 'simple';

    $defaults['container_class'] = 'nav-pagination';

    

    return $defaults;

}

add_filter( 'spyropress_pagination_defaults', 'spyropress_pagination_defaults' );



/**

 * oEmbed Modifier

 */

function oembed_modifier( $html ) {

    

    $html = preg_replace( '/(width|height|frameborder)="\d*"\s/', "", $html );

    

    if( is_str_contain( 'video-container', $html ) ) return $html;

    

    return '<div class="video-container">' . $html . '</div>';

}

add_filter( 'embed_oembed_html', 'oembed_modifier', 10 );

add_filter( 'oembed_result', 'oembed_modifier', 10 );